import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { StopHumanLoopRequest, StopHumanLoopResponse } from "../models/models_0";
import { SageMakerA2IRuntimeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerA2IRuntimeClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link StopHumanLoopCommand}.
 */
export interface StopHumanLoopCommandInput extends StopHumanLoopRequest {
}
/**
 * @public
 *
 * The output of {@link StopHumanLoopCommand}.
 */
export interface StopHumanLoopCommandOutput extends StopHumanLoopResponse, __MetadataBearer {
}
declare const StopHumanLoopCommand_base: {
    new (input: StopHumanLoopCommandInput): import("@smithy/smithy-client").CommandImpl<StopHumanLoopCommandInput, StopHumanLoopCommandOutput, SageMakerA2IRuntimeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: StopHumanLoopCommandInput): import("@smithy/smithy-client").CommandImpl<StopHumanLoopCommandInput, StopHumanLoopCommandOutput, SageMakerA2IRuntimeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Stops the specified human loop.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerA2IRuntimeClient, StopHumanLoopCommand } from "@aws-sdk/client-sagemaker-a2i-runtime"; // ES Modules import
 * // const { SageMakerA2IRuntimeClient, StopHumanLoopCommand } = require("@aws-sdk/client-sagemaker-a2i-runtime"); // CommonJS import
 * const client = new SageMakerA2IRuntimeClient(config);
 * const input = { // StopHumanLoopRequest
 *   HumanLoopName: "STRING_VALUE", // required
 * };
 * const command = new StopHumanLoopCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param StopHumanLoopCommandInput - {@link StopHumanLoopCommandInput}
 * @returns {@link StopHumanLoopCommandOutput}
 * @see {@link StopHumanLoopCommandInput} for command's `input` shape.
 * @see {@link StopHumanLoopCommandOutput} for command's `response` shape.
 * @see {@link SageMakerA2IRuntimeClientResolvedConfig | config} for SageMakerA2IRuntimeClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>We couldn't process your request because of an issue with the server. Try again
 *       later.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>We couldn't find the requested resource. Check that your resources exists and were created
 *       in the same AWS Region as your request, and try your request again. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>You exceeded
 *       the
 *       maximum number of requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The
 *       request isn't valid. Check the syntax and try again.</p>
 *
 * @throws {@link SageMakerA2IRuntimeServiceException}
 * <p>Base exception class for all service exceptions from SageMakerA2IRuntime service.</p>
 *
 *
 * @public
 */
export declare class StopHumanLoopCommand extends StopHumanLoopCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: StopHumanLoopRequest;
            output: {};
        };
        sdk: {
            input: StopHumanLoopCommandInput;
            output: StopHumanLoopCommandOutput;
        };
    };
}
